import { Link } from "wouter";
import {
  DropdownMenu,
  DropdownMenuContent,
  DropdownMenuItem,
  DropdownMenuTrigger,
} from "@/components/ui/dropdown-menu";
import { Menu, ChevronDown, X } from "lucide-react";
import { useState, useCallback, memo, useEffect } from "react";
import { useIsMobile } from "@/hooks/use-mobile";

// Define CS2 navigation links for dropdown
const CS2_NAV_LINKS = [
  { path: "/cs2-skin-trading-sites", label: "All Skin Sites", ariaLabel: "View all CS2 trading sites" },
  { path: "/cs2-bot-trading-sites", label: "Bot Trading", ariaLabel: "View CS2 bot trading sites" },
  { path: "/cs2-skin-p2p-sites", label: "P2P", ariaLabel: "View CS2 peer-to-peer trading sites" },
  { path: "/cs2-skin-insta-sell-sites", label: "Insta-Sell", ariaLabel: "View CS2 instant sell sites" },
  { path: "/cs2-skin-sites-with-paypal", label: "with PayPal", ariaLabel: "View CS2 trading sites with PayPal" },
  { path: "/cs2-skin-sites-with-crypto", label: "with Crypto", ariaLabel: "View CS2 trading sites with cryptocurrency" },
];

export const Navigation = memo(function Navigation() {
  const [mobileMenuOpen, setMobileMenuOpen] = useState(false);
  const isMobile = useIsMobile();
  
  // Close mobile menu when switching to desktop view
  useEffect(() => {
    if (!isMobile && mobileMenuOpen) {
      setMobileMenuOpen(false);
    }
  }, [isMobile, mobileMenuOpen]);

  // Toggle mobile menu with memoized callback
  const toggleMobileMenu = useCallback(() => {
    setMobileMenuOpen(prev => !prev);
  }, []);
  
  // Close mobile menu when a link is clicked
  const handleLinkClick = useCallback(() => {
    if (mobileMenuOpen) {
      setMobileMenuOpen(false);
    }
  }, [mobileMenuOpen]);

  return (
    <header className="sticky top-0 z-50 bg-background border-b border-accent">
      <nav className="w-full" aria-label="Main navigation">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex items-center justify-between h-16">
            <div className="flex items-center">
              <div className="flex-shrink-0">
                <Link href="/">
                  <a className="focus:outline-none focus:ring-2 focus:ring-primary rounded-md">
                    <span className="text-2xl font-bold bg-gradient-to-r from-primary to-purple-600 bg-clip-text text-transparent">
                      SkinRadar
                    </span>
                  </a>
                </Link>
              </div>
              <div className="hidden sm:block sm:ml-6">
                <div className="flex items-center space-x-4">
                  <DropdownMenu>
                    <DropdownMenuTrigger className="text-foreground hover:bg-accent px-3 py-2 rounded-md text-sm font-medium flex items-center gap-1 focus:outline-none focus:ring-2 focus:ring-primary" aria-label="CS2 categories">
                      CS2
                      <ChevronDown className="h-4 w-4" aria-hidden="true" />
                    </DropdownMenuTrigger>
                    <DropdownMenuContent>
                      {CS2_NAV_LINKS.map((link) => (
                        <Link key={link.path} href={link.path}>
                          <DropdownMenuItem 
                            className="cursor-pointer" 
                            onClick={handleLinkClick}
                            aria-label={link.ariaLabel}
                          >
                            {link.label}
                          </DropdownMenuItem>
                        </Link>
                      ))}
                    </DropdownMenuContent>
                  </DropdownMenu>
                  
                  <Link href="/rust-trading-sites">
                    <a className="text-foreground hover:bg-accent px-3 py-2 rounded-md text-sm font-medium focus:outline-none focus:ring-2 focus:ring-primary">
                      Rust
                    </a>
                  </Link>
                  
                  <Link href="/tf2-trading-sites">
                    <a className="text-foreground hover:bg-accent px-3 py-2 rounded-md text-sm font-medium focus:outline-none focus:ring-2 focus:ring-primary">
                      TF2
                    </a>
                  </Link>
                  
                  <Link href="/dota-2-trading-sites">
                    <a className="text-foreground hover:bg-accent px-3 py-2 rounded-md text-sm font-medium focus:outline-none focus:ring-2 focus:ring-primary">
                      Dota 2
                    </a>
                  </Link>
                </div>
              </div>
            </div>

            {/* Mobile menu button */}
            <div className="sm:hidden">
              <button
                onClick={toggleMobileMenu}
                className="text-foreground hover:bg-accent p-2 rounded-md focus:outline-none focus:ring-2 focus:ring-primary"
                aria-label={mobileMenuOpen ? "Close menu" : "Open menu"}
                aria-expanded={mobileMenuOpen}
                aria-controls="mobile-menu"
              >
                {mobileMenuOpen ? (
                  <X className="h-6 w-6" aria-hidden="true" />
                ) : (
                  <Menu className="h-6 w-6" aria-hidden="true" />
                )}
              </button>
            </div>
          </div>
        </div>

        {/* Mobile menu */}
        <div 
          id="mobile-menu" 
          className={`sm:hidden bg-background border-b border-accent ${mobileMenuOpen ? 'block' : 'hidden'}`}
          aria-hidden={!mobileMenuOpen}
        >
          <div className="px-2 pt-2 pb-3 space-y-1">
            {CS2_NAV_LINKS.map((link) => (
              <Link key={link.path} href={link.path}>
                <a 
                  className="text-foreground hover:bg-accent block px-3 py-2 rounded-md text-base font-medium focus:outline-none focus:ring-2 focus:ring-primary" 
                  aria-label={link.ariaLabel}
                  onClick={handleLinkClick}
                >
                  {link.label}
                </a>
              </Link>
            ))}

            <Link href="/rust-trading-sites">
              <a 
                className="text-foreground hover:bg-accent block px-3 py-2 rounded-md text-base font-medium focus:outline-none focus:ring-2 focus:ring-primary"
                onClick={handleLinkClick}
              >
                Rust
              </a>
            </Link>

            <Link href="/tf2-trading-sites">
              <a 
                className="text-foreground hover:bg-accent block px-3 py-2 rounded-md text-base font-medium focus:outline-none focus:ring-2 focus:ring-primary"
                onClick={handleLinkClick}
              >
                TF2
              </a>
            </Link>

            <Link href="/dota-2-trading-sites">
              <a 
                className="text-foreground hover:bg-accent block px-3 py-2 rounded-md text-base font-medium focus:outline-none focus:ring-2 focus:ring-primary"
                onClick={handleLinkClick}
              >
                Dota 2
              </a>
            </Link>
          </div>
        </div>
      </nav>
    </header>
  );
});